# Generated by Django 5.0.1 on 2024-02-18 15:00

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("artd_customer", "0002_customergroup_customer_customer_group_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="customer",
            name="external_id",
            field=models.CharField(
                blank=True,
                help_text="External ID of the object.",
                max_length=100,
                null=True,
                verbose_name="External ID",
            ),
        ),
        migrations.AddField(
            model_name="customer",
            name="source",
            field=models.JSONField(
                blank=True,
                help_text="Source of the object.",
                null=True,
                verbose_name="Source",
            ),
        ),
        migrations.AddField(
            model_name="customeradditionalfields",
            name="external_id",
            field=models.CharField(
                blank=True,
                help_text="External ID of the object.",
                max_length=100,
                null=True,
                verbose_name="External ID",
            ),
        ),
        migrations.AddField(
            model_name="customeradditionalfields",
            name="source",
            field=models.JSONField(
                blank=True,
                help_text="Source of the object.",
                null=True,
                verbose_name="Source",
            ),
        ),
        migrations.AddField(
            model_name="customeraddress",
            name="external_id",
            field=models.CharField(
                blank=True,
                help_text="External ID of the object.",
                max_length=100,
                null=True,
                verbose_name="External ID",
            ),
        ),
        migrations.AddField(
            model_name="customeraddress",
            name="source",
            field=models.JSONField(
                blank=True,
                help_text="Source of the object.",
                null=True,
                verbose_name="Source",
            ),
        ),
        migrations.AddField(
            model_name="customergroup",
            name="external_id",
            field=models.CharField(
                blank=True,
                help_text="External ID of the object.",
                max_length=100,
                null=True,
                verbose_name="External ID",
            ),
        ),
        migrations.AddField(
            model_name="customergroup",
            name="source",
            field=models.JSONField(
                blank=True,
                help_text="Source of the object.",
                null=True,
                verbose_name="Source",
            ),
        ),
        migrations.AddField(
            model_name="customergroupchangelog",
            name="external_id",
            field=models.CharField(
                blank=True,
                help_text="External ID of the object.",
                max_length=100,
                null=True,
                verbose_name="External ID",
            ),
        ),
        migrations.AddField(
            model_name="customergroupchangelog",
            name="source",
            field=models.JSONField(
                blank=True,
                help_text="Source of the object.",
                null=True,
                verbose_name="Source",
            ),
        ),
        migrations.AddField(
            model_name="customertag",
            name="external_id",
            field=models.CharField(
                blank=True,
                help_text="External ID of the object.",
                max_length=100,
                null=True,
                verbose_name="External ID",
            ),
        ),
        migrations.AddField(
            model_name="customertag",
            name="source",
            field=models.JSONField(
                blank=True,
                help_text="Source of the object.",
                null=True,
                verbose_name="Source",
            ),
        ),
        migrations.AddField(
            model_name="tag",
            name="external_id",
            field=models.CharField(
                blank=True,
                help_text="External ID of the object.",
                max_length=100,
                null=True,
                verbose_name="External ID",
            ),
        ),
        migrations.AddField(
            model_name="tag",
            name="source",
            field=models.JSONField(
                blank=True,
                help_text="Source of the object.",
                null=True,
                verbose_name="Source",
            ),
        ),
    ]



from django.core.management.base import BaseCommand
from artd_customer.models import CustomerGroup

CUSTOMER_GROUPS = [
    {
        "group_code": "new",
        "group_name": "New customers",
        "description": "New customers",
    },
    {
        "group_code": "wholesale",
        "group_name": "Wholesale customers",
        "description": "Wholesale customers",
    },
    {
        "group_code": "vip",
        "group_name": "VIP customers",
        "description": "VIP customers",
    },
]

class Command(BaseCommand):
    help = 'Create the base customer groups.'

    def handle(self, *args, **options):
        for group in CUSTOMER_GROUPS:
            if CustomerGroup.objects.filter(group_code=group["group_code"]).count()==0:
                CustomerGroup.objects.create(
                    group_code=group["group_code"],
                    group_name=group["group_name"],
                    group_description=group["description"],
                )
                self.stdout.write(self.style.WARNING(f'Customer group {group["group_code"]} created'))
            else:
                CustomerGroup.objects.filter(group_code=group["group_code"]).update(
                    group_name=group["group_name"],
                    group_description=group["description"],
                )
                self.stdout.write(self.style.ERROR(f'Customer group {group["group_code"]} updated'))
        
